# couscous

Derive actionable rules from specification prose through first grinding grains into small balls to later cook a good meal.

[License: MIT](https://github.com/sthagen/couscous/blob/default/LICENSE)

[![version](https://img.shields.io/pypi/v/couscous.svg?style=flat)](https://pypi.python.org/pypi/couscous/)
[![downloads](https://pepy.tech/badge/couscous/month)](https://pepy.tech/project/couscous)
[![wheel](https://img.shields.io/pypi/wheel/couscous.svg?style=flat)](https://pypi.python.org/pypi/couscous/)
[![supported-versions](https://img.shields.io/pypi/pyversions/couscous.svg?style=flat)](https://pypi.python.org/pypi/couscous/)
[![supported-implementations](https://img.shields.io/pypi/implementation/couscous.svg?style=flat)](https://pypi.python.org/pypi/couscous/)

## Documentation

User and developer [documentation of couscous](https://codes.dilettant.life/docs/couscous).

## Bug Tracker

Feature requests and bug reports are bested entered in the [todos of couscous](https://todo.sr.ht/~sthagen/couscous).

## Primary Source repository

The primary source repository of [couscous is at sourcehut](https://git.sr.ht/~sthagen/couscous)
a collection of tools useful for software development.
